@@ -195,11 +195,12 @@ QVariant AbstractKeyListModel::headerData(int section, Qt::Orientation o, int ro
             switch (section) {
             case PrettyName:       return i18n("Name");
             case PrettyEMail:      return i18n("E-Mail");
-            case Validity:         return i18n("Validity");
+            case Validity:         return i18n("User-IDs");
             case ValidFrom:        return i18n("Valid From");
             case ValidUntil:       return i18n("Valid Until");
             case TechnicalDetails: return i18n("Details");
             case ShortKeyID:       return i18n("Key-ID");
+            case KeyID:            return i18n("Key-ID");
             case NumColumns:;
             }
     return QVariant();
@@ -247,8 +248,8 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
             } else {
                 return QVariant();
             }
-	case Validity:
-	    return Formatting::complianceStringShort(key);
+        case Validity:
+            return Formatting::complianceStringShort(key);
         case ValidFrom:
             if (role == Qt::EditRole) {
                 return Formatting::creationDate(key);
@@ -265,6 +266,8 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
             return Formatting::type(key);
         case ShortKeyID:
             return QString::fromLatin1(key.shortKeyID());
+        case KeyID:
+            return Formatting::prettyID(key.keyID());
         case Summary:
             return Formatting::summaryLine(key);
         case NumColumns:
@@ -273,7 +276,7 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
     } else if (role == Qt::ToolTipRole) {
         return Formatting::toolTip(key, toolTipOptions());
     } else if (role == Qt::FontRole) {
-        return KeyFilterManager::instance()->font(key, (column == ShortKeyID) ? QFont(QStringLiteral("courier")) : QFont());
+        return KeyFilterManager::instance()->font(key, (column == ShortKeyID || column == KeyID) ? QFont(QStringLiteral("monospace")) : QFont());
     } else if (role == Qt::DecorationRole) {
         return column == Icon ? returnIfValid(KeyFilterManager::instance()->icon(key)) : QVariant();
     } else if (role == Qt::BackgroundRole) {
@@ -324,7 +327,7 @@ class FlatKeyListModel
     Q_OBJECT
 public:
     explicit FlatKeyListModel(QObject *parent = nullptr);
-    ~FlatKeyListModel();
+    ~FlatKeyListModel() override;
 
     int rowCount(const QModelIndex &pidx) const override
     {
@@ -349,7 +352,7 @@ class HierarchicalKeyListModel : public AbstractKeyListModel
     Q_OBJECT
 public:
     explicit HierarchicalKeyListModel(QObject *parent = nullptr);
-    ~HierarchicalKeyListModel();
+    ~HierarchicalKeyListModel() override;
 
     int rowCount(const QModelIndex &pidx) const override;
     using AbstractKeyListModel::index;
